==> 2.5.zip: piwigo/language/en_GB/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: English [GB]
Version: 2.5.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=716
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "English";
$lang_info['country'] = "Great Britain";
$lang_info['direction'] = "ltr";
$lang_info['code'] = "en";
$lang_info['zero_plural'] = true;
$lang_info['parent']= "en_UK";

$lang['%d photo is also linked to current tags'] = "%d photo is also linked to current keywords";
$lang['%d photos are also linked to current tags'] = "%d photos are also linked to current keywords";
$lang['add this photo to your favorites'] = "add this photo to your favourites";
$lang['All tags'] = "All keywords";
$lang['About Piwigo'] = "About this website";
$lang['An administrator must authorize your comment before it is visible.'] = "An administrator must authorise your comment before it becomes visible.";
$lang['Any tag'] = "Any keyword";
$lang['customize the appareance of the gallery'] = "customise the look of the gallery";
$lang['Customize'] = "Customise";
$lang['delete all photos from your favorites'] = "delete all photos from your favourites";
$lang['delete this photo from your favorites'] = "delete this photo from your favourites";
$lang['Favorites'] = "Favourites";
$lang['display available tags'] = "display available keywords";
$lang['display photos linked to this tag'] = "display photos linked to this keyword";
$lang['Related tags'] = "Related keywords";
$lang['remove this tag from the list'] = "remove this keyword from the list";
$lang['Requested tag does not exist'] = 'Requested keyword does not exist';
$lang['Search tags'] = "Search keywords";
$lang['show tag cloud'] = "show keywords ungrouped";
$lang['Tag results for'] = "Keyword results for";
$lang['Tag'] = "Keyword";
$lang['Tags'] = "Keywords";
$lang['Your favorites'] = "Your favourites";
$lang['Your Gallery Customization'] = "Your gallery customisation";


$lang['no rate'] = 'no rating';
$lang['display your favorites photos'] = 'display your favourite photos';
$lang['You are not authorized to access the requested page'] = 'You are not authorised to access the requested page';
$lang['Successfully registered, you will soon receive an email with your connection settings. Welcome!'] = 'Successfully registered; you will soon receive an email with your connection settings. Welcome!';
$lang['Please, enter a login'] = 'Please enter a login';
$lang['Piwigo encountered a non recoverable error'] = 'Piwigo encountered an irrecoverable error';
?>

==> 2.9.zip: piwigo/language/en_GB/common.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: English [GB]
Version: auto
Language URI: http://piwigo.org/ext/extension_view.php?eid=716
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "English";
$lang_info['country'] = "Great Britain";
$lang_info['direction'] = "ltr";
$lang_info['code'] = "en";
$lang_info['zero_plural'] = true;
$lang_info['parent']= "en_UK";

$lang['%d photo is also linked to current tags'] = "%d photo is also linked to current keywords";
$lang['%d photos are also linked to current tags'] = "%d photos are also linked to current keywords";
$lang['add this photo to your favorites'] = "add this photo to your favourites";
$lang['All tags'] = "All keywords";
$lang['About Piwigo'] = "About this website";
$lang['An administrator must authorize your comment before it is visible.'] = "An administrator must authorise your comment before it becomes visible.";
$lang['Any tag'] = "Any keyword";
$lang['customize the appareance of the gallery'] = "customise the look of the gallery";
$lang['Customize'] = "Customise";
$lang['delete all photos from your favorites'] = "delete all photos from your favourites";
$lang['delete this photo from your favorites'] = "delete this photo from your favourites";
$lang['Favorites'] = "Favourites";
$lang['display available tags'] = "display available keywords";
$lang['display photos linked to this tag'] = "display photos linked to this keyword";
$lang['Related tags'] = "Related keywords";
$lang['remove this tag from the list'] = "remove this keyword from the list";
$lang['Requested tag does not exist'] = 'Requested keyword does not exist';
$lang['Search tags'] = "Search keywords";
$lang['show tag cloud'] = 'show keywords cloud';
$lang['Tag results for'] = "Keyword results for";
$lang['Tag'] = "Keyword";
$lang['Tags'] = "Keywords";
$lang['Your favorites'] = "Your favourites";
$lang['Your Gallery Customization'] = "Your gallery customisation";


$lang['no rate'] = 'no rating';
$lang['display your favorites photos'] = 'display your favourite photos';
$lang['You are not authorized to access the requested page'] = 'You are not authorised to access the requested page';
$lang['Successfully registered, you will soon receive an email with your connection settings. Welcome!'] = 'Successfully registered.  You will soon receive an email with your connection settings. Welcome!';
$lang['Please, enter a login'] = 'Please enter a login';
$lang['Piwigo encountered a non recoverable error'] = 'Piwigo encountered an irrecoverable error';
$lang['Forgot your password?'] = 'Forgotten your password?';
$lang['small'] = 'S - small';
$lang['square'] = 'Square';
$lang['stop the slideshow'] = 'stop the slideshow';
$lang['thumb'] = 'Thumbnail';
$lang['today'] = 'today';
$lang['useful when password forgotten'] = 'useful in case password is forgotten';
$lang['wrong date'] = 'wrong date';
$lang['xlarge'] = 'XL - extra large';
$lang['medium'] = 'M - medium';
$lang['month']['10'] = 'October';
$lang['month']['11'] = 'November';
$lang['month']['12'] = 'December';
$lang['month']['1'] = 'January';
$lang['month']['2'] = 'February';
$lang['month']['3'] = 'March';
$lang['month']['4'] = 'April';
$lang['month']['5'] = 'May';
$lang['month']['6'] = 'June';
$lang['month']['7'] = 'July';
$lang['month']['8'] = 'August';
$lang['month']['9'] = 'September';
$lang['obligatory'] = 'mandatory';
$lang['password updated'] = 'password updated';
$lang['photo'] = 'photo';
$lang['photos posted during the last %d days'] = 'photos posted during the last %d days';
$lang['posted after %s (%s)'] = 'posted after %s (%s)';
$lang['posted before %s (%s)'] = 'posted before %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'posted between %s (%s) and %s (%s)';
$lang['xsmall'] = 'XS - extra small';
$lang['xxlarge'] = 'XXL - huge';
